@@ -72,7 +72,7 @@ use vars qw( $locale $Locale %locale );
 ## ----------------------------------------------------------------------
 
 ## ----------------------------------------------------------------------
-use vars qw( @element $element $event %unkown_warn_done );
+use vars qw( @element $element $event %unknown_warn_done );
 use vars qw( @p_length );
 use vars qw( $in_author $in_translator );
 use vars qw( $heading_level $toc_detail );
@@ -106,7 +106,7 @@ sub start_element
     my $file = $event->file;
     my $line = $event->line;
     warn "unknown start element $name at $file:$line\n"
-	unless $unkown_warn_done{$name}++;
+	unless $unknown_warn_done{$name}++;
 }
 sub end_element
 {
@@ -115,7 +115,7 @@ sub end_element
     my $file = $event->file;
     my $line = $event->line;
     warn "unknown end element $name at $file:$line\n"
-	unless $unkown_warn_done{ $name }++;
+	unless $unknown_warn_done{ $name }++;
 }
 
 ## ----------------------------------------------------------------------
