@@ -65,19 +65,21 @@ use vars qw( @copyrightsummaries );
 ## ----------------------------------------------------------------------
 sub _output_start_book
 {
-    output( "\\documentclass[11pt,$locale{ 'babel' }]{book}\n" );
+    output( "\\documentclass[11pt" );
+    output( ",$locale{ 'babel' }" ) 
+    	if (length( $locale{ 'babel' } ));
+    output( "]{book}\n" );
     output( "\n" );
-    output( "\\usepackage[$locale{ 'inputenc' }]{inputenc}\n" )
+    output( "\\usepackage[$locale{ 'inputenc' }]{inputenc}\n\n" )
 	if length( $locale{ 'inputenc' } );
-    output( "\n" );
     output( "\\usepackage[T1]{fontenc}\n" );
     output( "\n" );
     output( "\\usepackage{pifont}\n" );
     output( "\\usepackage{textcomp}\n" );
     output( "\\usepackage{wasysym}\n" );
     output( "\n" );
-    output( "\\usepackage{babel}\n" );
-    output( "\n" );
+    output( "\\usepackage{babel}\n\n" )
+        if length( $locale{ 'babel' } );
     output( "\\usepackage{helvet}\n" );
     output( "\\usepackage{palatino}\n" );
     output( "\n" );
@@ -123,7 +125,10 @@ sub _output_start_book
     output( "\\ifx\\pdfoutput\\undefined\n" );
     output( "\\usepackage[hypertex,colorlinks=true]{hyperref}\n" );
     output( "\\else\n" );
-    output( "\\usepackage[pdftex,colorlinks=true]{hyperref}\n" );
+    output( "\\usepackage[pdftex,colorlinks=true" );
+    output( ",$locale{ 'pdfhyperref' }" )
+    	if (length( $locale{ 'pdfhyperref' } ));
+    output( "]{hyperref}\n" );
     output( "\\fi\n" );
     output( "\n" );
     output( "\\parindent=0pt\n" );
@@ -134,11 +139,14 @@ sub _output_start_book
     output( "\n" );
     output( "\\sloppy\n" );
     output( "\n" );
+    output( "$locale{ 'before begin document' }\n" );
     output( "\\begin{document}\n" );
+    output( "$locale{ 'after begin document' }\n" );
 }
 sub _output_end_book
 {
     output( "\n" );
+    output( "$locale{ 'before end document' }\n" );
     output( "\\end{document}\n");
     output( "\n" );
 }
@@ -632,7 +640,7 @@ sub _cdata
 	}
 	
 	# dots should be ellipsis "..."
-	s/\.\.\./\\dots /g;
+	s/\.\.\./\\dots{}/g;
 
     }
 
