@@ -58,6 +58,21 @@ use vars qw( %locale_aliases );
 		   'es_ES.ISO8859-15	'	=> 'es_ES.ISO8859-15',
 		   'es_ES.ISO8859-15@euro'	=> 'es_ES.ISO8859-15',
 
+		   'eu'				=> 'eu_ES.ISO8859-1',
+		   'eu_ES'			=> 'eu_ES.ISO8859-1',
+		   'eu_ES.ISO8859-1'		=> 'eu_ES.ISO8859-1',
+
+		   'eu_ES@euro'			=> 'eu_ES.ISO8859-15',
+		   'eu_ES.ISO8859-15	'	=> 'eu_ES.ISO8859-15',
+		   'eu_ES.ISO8859-15@euro'	=> 'eu_ES.ISO8859-15',
+
+		   'eu_FR'			=> 'eu_FR.ISO8859-1',
+		   'eu_FR.ISO8859-1'		=> 'eu_FR.ISO8859-1',
+
+		   'eu_FR@euro'			=> 'eu_FR.ISO8859-15',
+		   'eu_FR.ISO8859-15	'	=> 'eu_FR.ISO8859-15',
+		   'eu_FR.ISO8859-15@euro'	=> 'eu_FR.ISO8859-15',
+
 		   'fi'				=> 'fi_FI.ISO8859-1',
 		   'fi_FI'			=> 'fi_FI.ISO8859-1',
 		   'fi_FI.ISO8859-1'		=> 'fi_FI.ISO8859-1',
@@ -126,6 +141,10 @@ use vars qw( %locale_aliases );
 		   'pt_PT.ISO8859-15'		=> 'pt_PT.ISO8859-15',
 		   'pt_PT.ISO8859-15@euro'	=> 'pt_PT.ISO8859-15',
 
+		   'ro'				=> 'ro_RO.ISO8859-2',
+		   'ro_RO'			=> 'ro_RO.ISO8859-2',
+		   'ro_RO.ISO8859-2'		=> 'ro_RO.ISO8859-2',
+
 		   'ru'				=> 'ru_RU.KOI8-R',
 		   'ru_RU'			=> 'ru_RU.KOI8-R',
 		   'ru_RU.KOI8-R'		=> 'ru_RU.KOI8-R',
@@ -134,6 +153,10 @@ use vars qw( %locale_aliases );
 		   'sk_SK'			=> 'sk_SK.ISO8859-2',
 		   'sk_SK.ISO8859-2'		=> 'sk_SK.ISO8859-2',
 
+		   'sl'                         => 'sl_SI.ISO8859-2',
+		   'sl_SI'                      => 'sl_SI.ISO8859-2',
+		   'sl_SI.ISO8859-2'            => 'sl_SI.ISO8859-2',
+
 		   'tr'				=> 'tr_TR.ISO8859-9',
 		   'tr_TR'			=> 'tr_TR.ISO8859-9',
 		   'tr_TR.ISO8859-9'		=> 'tr_TR.ISO8859-9',
